Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(87)

Unified Diff: pkg/mdv/test/analyzer_test.dart

Issue 20886002: add custom_element package (Closed) Base URL: https://dart.googlecode.com/svn/branches/bleeding_edge/dart
Patch Set: Created 7 years, 5 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « pkg/mdv/lib/src/template_iterator.dart ('k') | pkg/observe/lib/src/observable.dart » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: pkg/mdv/test/analyzer_test.dart
diff --git a/samples/tests/samples/standalone/time_test.dart b/pkg/mdv/test/analyzer_test.dart
similarity index 61%
copy from samples/tests/samples/standalone/time_test.dart
copy to pkg/mdv/test/analyzer_test.dart
index 32a8726ccaba707e59d14c9eb5589b446682c6d3..68f5e85509a1b293e9079970724136e0de1c1b46 100644
--- a/samples/tests/samples/standalone/time_test.dart
+++ b/pkg/mdv/test/analyzer_test.dart
@@ -2,13 +2,11 @@
// for details. All rights reserved. Use of this source code is governed by a
// BSD-style license that can be found in the LICENSE file.
-import '../../../time/time_server.dart' as time;
+library mdv.test.analyzer_test;
-// @static-clean
+import 'package:mdv/mdv.dart';
-/**
- * This test exists to ensure that the time sample compiles without errors.
- */
-void main() {
+// @static-clean
-}
+// This test ensures MDV compiles without errors.
+void main() {}
« no previous file with comments | « pkg/mdv/lib/src/template_iterator.dart ('k') | pkg/observe/lib/src/observable.dart » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698